# Generated by Django 2.2.24 on 2022-01-13 04:22

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SiteConfigClientEnabled',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('site_uuid', models.UUIDField(unique=True, verbose_name='UUID of the site the client enabled for.')),
                ('note', models.CharField(max_length=255, verbose_name='Note for the the admin.')),
            ],
        ),
    ]
